# main.py -- put your code here!

from umqttsimple import MQTTClient
import time
import ubinascii
from machine import WDT
import network
import os
import config
import secrets

last_message = 0
message_interval = 5
counter = 0
ringFlag = False
wdt = None
wdtCnt = 0
client = None

def init():
    wlan = network.WLAN(network.STA_IF)
    wlan.active(True)
    wlan.connect(config.ssid, secrets.wpakey)

    while (not wlan.isconnected()):
        print('Not yet connected to WLAN')

    print('Connected to WLAN')

    global client
    clientId = ubinascii.hexlify(bytearray(os.urandom(16))).decode()
    client = MQTTClient(clientId, config.mqtt_server, keepalive=60, ssl=True)
    client.set_callback(mqtt_callback)
    client.connect()
    client.subscribe(config.watchdog_topic)
    print(f"Connected to {config.mqtt_server} MQTT Broker")

    global wdt
    wdt = WDT(timeout=5000)
    wdt.feed()
    print("Watchdog enabled")


def mqtt_callback(topic, msg):
    global wdt, wdtCnt
    print(f"Received: {topic}: {msg}")
    if topic == config.watchdog_topic:
        wdtCnt += 1
        print(f"feed watchdog {wdtCnt}")
        wdt.feed()

def main():
    global client
    print("Hello")
    time.sleep(1)

    try:
        init()
    except Exception as e:
        print(f"Some error when starting: {e}")
        time.sleep(15)
        machine.reset()

    last_time = time.ticks_ms()
    while True:
        current_time = time.ticks_ms()

        if (time.ticks_diff(current_time, last_time) > 250):
            last_time = current_time
            client.ping()
            client.wait_msg()


    client.disconnect()
    
if __name__ == "__main__":
    main()